@@ -2,12 +2,13 @@
 from robster.model import LinearModel
 
 class SingleLayerPerceptron:
-  def __init__(self, epochs, mini_batch, learning_rate = 3e-3, report = 1, MODEL = LinearModel):
+  # def __init__(self, epochs, mini_batch, learning_rate = 3e-3, report = 1, MODEL = LinearModel):
+  def __init__(self, epochs, mini_batch, learning_rate = 3e-3, report = 1):
     self.epochs_ = epochs
     self.mini_batch_ = mini_batch
     self.learning_rate_ = learning_rate
     self.report_=report
-    self.MODEL_ = MODEL
+    self.MODEL_ = LinearModel
 
 
   def fit(self, X, y):
